enumBisonSymbolForm
enum BisonSymbolForm
Restricted visibility: declared "@visibility root". Code outside that scope must not name this declaration.
How a symbol was written on the right-hand side of a rule.
Cases
case Identifiercase CharLiteralTest cases 23
Test cases that cover or call this symbol, from the coverage report and from the analyzed test sources.
Dedicated tests 2
Other tests reaching this symbol 21
BisonAlternativeNodeTest::testExposesEveryPartOfTheAlternativecallsBisonSymbolNodeTest::testTypecallsBisonSymbolNodeTest::testValuecallsBisonParserTest::testParseRuleWithCharLiteralSymbolcallsGrammarCompilerTest::testCompilecallsGrammarCompilerTest::testCompileDiscardsActionAndPrecedencecallsGrammarCompilerTest::testCompileDistinguishesTerminalsAndNonTerminalscallsGrammarCompilerTest::testCompileIgnoresNonTokenDeclarationscallsGrammarCompilerTest::testCompileMergesSameNameRulescallsGrammarCompilerTest::testCompileMergesSameNameRulesPreservesBisonStructurecallsGrammarCompilerTest::testCompileMultipleAlternativescallsGrammarCompilerTest::testCompilePreservesBisonStructurecallsGrammarCompilerTest::testCompileThrowsOnUnknownSymbolcallsGrammarCompilerTest::testCompileThrowsOnUnknownSymbolPreservesBisonStructurecallsGrammarCompilerTest::testCompileWithMultipleAlternativescallsGrammarCompilerTest::testCompileWithMultipleDistinctRulescallsBisonAlternativeDraftTest::testAddSymbolKeepsTheOrderTheSymbolsWereReadcallsBisonAlternativeDraftTest::testCompleteStartsANewAlternativeSoNothingCarriesOvercallsBisonAlternativeReaderTest::testReadPartAddsACharacterSymbolcallsBisonAlternativeReaderTest::testReadPartAddsANamedSymbolcallsBisonRuleReaderTestcalls
Relations
Constant reads 3
- class-const SqlFaker\Compiler\Bison\GrammarCompiler::compile() packages/sql-faker/src/Compiler/Bison/GrammarCompiler.php:57
- class-const SqlFaker\Compiler\Bison\Rule\BisonAlternativeReader::readPart() packages/sql-faker/src/Compiler/Bison/Rule/BisonAlternativeReader.php:91
- class-const SqlFaker\Compiler\Bison\Rule\BisonAlternativeReader::readPart() packages/sql-faker/src/Compiler/Bison/Rule/BisonAlternativeReader.php:94